game_qu.base.important_constants API documentation
Description: Some important constants for the game. None of these values should be changed unless you know what you are doing.

# Module `game_qu.base.important_constants`

Some important constants for the game. None of these values should be changed unless you know what you are doing.

Expand source code

    """Some important constants for the game. None of these values should be changed unless you know what you are doing."""

    SCREEN_LENGTH = 1300
    SCREEN_HEIGHT = 650
    BACKGROUND_COLOR = (200, 200, 200)
    NUMBER_OF_FRAMES_HISTORY_KEEPER_STORES = 4
    IS_USING_CONTROLLER = False
    DEFAULT_RENDERING_ENGINE = "pygame"